==> ejc-proequipmentcorp-impl-3.0.0-20221124.024157-181-sources.jar: com/ejianc/business/proequipmentcorprent/ac/vo/ContractOtherCostVO.java <==
package com.ejianc.business.proequipmentcorprent.ac.vo;

import java.math.*;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 安拆合同其他金额
 * 
 * @author generator
 * 
 */
public class ContractOtherCostVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String treeIndex; // 序号
    private String costName; // 费用名称
    private BigDecimal costNum; // 数量
    private BigDecimal costPrice; // 单价（无税）
    private BigDecimal costTaxRate; // 税率
    private BigDecimal costTaxPrice; // 单价（含税）
    private BigDecimal costMny; // 金额无税
    private BigDecimal costTaxMny; // 金额（含税）
    private BigDecimal costTax; // 税金
    private String costMemo; // 备注
    private Long changeId; // 变更主键
    private Long srcTblId; // 来源子表主键
    private BigDecimal beforeChangeCostNum; // 变更前数量
    private BigDecimal beforeChangeCostPrice; // 变更前单价(无税)
    private BigDecimal beforeChangeCostRate; // 变更前税率
    private String changeType; // 变更类型
    private Long contractId; // 所属合同Id
    

    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getCostNum() {
        return costNum;
    }

    public void setCostNum(BigDecimal costNum) {
        this.costNum = costNum;
    }
    public BigDecimal getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(BigDecimal costPrice) {
        this.costPrice = costPrice;
    }
    public BigDecimal getCostTaxRate() {
        return costTaxRate;
    }

    public void setCostTaxRate(BigDecimal costTaxRate) {
        this.costTaxRate = costTaxRate;
    }
    public BigDecimal getCostTaxPrice() {
        return costTaxPrice;
    }

    public void setCostTaxPrice(BigDecimal costTaxPrice) {
        this.costTaxPrice = costTaxPrice;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public BigDecimal getCostTaxMny() {
        return costTaxMny;
    }

    public void setCostTaxMny(BigDecimal costTaxMny) {
        this.costTaxMny = costTaxMny;
    }
    public BigDecimal getCostTax() {
        return costTax;
    }

    public void setCostTax(BigDecimal costTax) {
        this.costTax = costTax;
    }
    public String getCostMemo() {
        return costMemo;
    }

    public void setCostMemo(String costMemo) {
        this.costMemo = costMemo;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }
    public BigDecimal getBeforeChangeCostNum() {
        return beforeChangeCostNum;
    }

    public void setBeforeChangeCostNum(BigDecimal beforeChangeCostNum) {
        this.beforeChangeCostNum = beforeChangeCostNum;
    }
    public BigDecimal getBeforeChangeCostPrice() {
        return beforeChangeCostPrice;
    }

    public void setBeforeChangeCostPrice(BigDecimal beforeChangeCostPrice) {
        this.beforeChangeCostPrice = beforeChangeCostPrice;
    }
    public BigDecimal getBeforeChangeCostRate() {
        return beforeChangeCostRate;
    }

    public void setBeforeChangeCostRate(BigDecimal beforeChangeCostRate) {
        this.beforeChangeCostRate = beforeChangeCostRate;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20221227.095802-272-sources.jar: com/ejianc/business/proequipmentcorprent/ac/vo/ContractOtherCostVO.java <==
package com.ejianc.business.proequipmentcorprent.ac.vo;

import java.math.*;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 安拆合同其他金额
 * 
 * @author generator
 * 
 */
public class ContractOtherCostVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String treeIndex; // 序号
    private String costName; // 费用名称
    private BigDecimal costNum; // 数量
    private BigDecimal costPrice; // 单价（无税）
    private BigDecimal costTaxRate; // 税率
    private BigDecimal costTaxPrice; // 单价（含税）
    private BigDecimal costMny; // 金额无税
    private BigDecimal costTaxMny; // 金额（含税）
    private BigDecimal costTax; // 税金
    private String costMemo; // 备注
    private Long changeId; // 变更主键
    private Long srcTblId; // 来源子表主键
    private BigDecimal beforeChangeCostNum; // 变更前数量
    private BigDecimal beforeChangeCostPrice; // 变更前单价(无税)
    private BigDecimal beforeChangeCostRate; // 变更前税率
    private String changeType; // 变更类型
    private Long contractId; // 所属合同Id
    private String costTaxRateStr;
    private String costTaxMnyStr;
    private String costTaxStr;
    private String costMnyStr;


    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getCostNum() {
        return costNum;
    }

    public void setCostNum(BigDecimal costNum) {
        this.costNum = costNum;
    }
    public BigDecimal getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(BigDecimal costPrice) {
        this.costPrice = costPrice;
    }
    public BigDecimal getCostTaxRate() {
        return costTaxRate;
    }

    public void setCostTaxRate(BigDecimal costTaxRate) {
        this.costTaxRate = costTaxRate;
    }
    public BigDecimal getCostTaxPrice() {
        return costTaxPrice;
    }

    public void setCostTaxPrice(BigDecimal costTaxPrice) {
        this.costTaxPrice = costTaxPrice;
    }
    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }
    public BigDecimal getCostTaxMny() {
        return costTaxMny;
    }

    public void setCostTaxMny(BigDecimal costTaxMny) {
        this.costTaxMny = costTaxMny;
    }
    public BigDecimal getCostTax() {
        return costTax;
    }

    public void setCostTax(BigDecimal costTax) {
        this.costTax = costTax;
    }
    public String getCostMemo() {
        return costMemo;
    }

    public void setCostMemo(String costMemo) {
        this.costMemo = costMemo;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }
    public BigDecimal getBeforeChangeCostNum() {
        return beforeChangeCostNum;
    }

    public void setBeforeChangeCostNum(BigDecimal beforeChangeCostNum) {
        this.beforeChangeCostNum = beforeChangeCostNum;
    }
    public BigDecimal getBeforeChangeCostPrice() {
        return beforeChangeCostPrice;
    }

    public void setBeforeChangeCostPrice(BigDecimal beforeChangeCostPrice) {
        this.beforeChangeCostPrice = beforeChangeCostPrice;
    }
    public BigDecimal getBeforeChangeCostRate() {
        return beforeChangeCostRate;
    }

    public void setBeforeChangeCostRate(BigDecimal beforeChangeCostRate) {
        this.beforeChangeCostRate = beforeChangeCostRate;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getCostTaxRateStr() {
        return costTaxRateStr;
    }

    public void setCostTaxRateStr(String costTaxRateStr) {
        this.costTaxRateStr = costTaxRateStr;
    }

    public String getCostTaxMnyStr() {
        return costTaxMnyStr;
    }

    public void setCostTaxMnyStr(String costTaxMnyStr) {
        this.costTaxMnyStr = costTaxMnyStr;
    }

    public String getCostTaxStr() {
        return costTaxStr;
    }

    public void setCostTaxStr(String costTaxStr) {
        this.costTaxStr = costTaxStr;
    }

    public String getCostMnyStr() {
        return costMnyStr;
    }

    public void setCostMnyStr(String costMnyStr) {
        this.costMnyStr = costMnyStr;
    }
}
